<?php

/*
 
 File: problem.php3
 $Author: rkrusty $
 $Revision: 1.4 $
 $Date: 1999/03/31 10:52:25 $
 
 IMP: Copyright 1999 Charles J. Hagenbuch <chuck@horde.org>
 
 You should have received a copy of the GNU Public
 License along with this package; if not, write to the
 Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 Boston, MA 02111-1307, USA.
 
 */

/* format a from: address correctly based on all relevant factors... */
function get_from($user, $server) {
   global $default, $from;
   
   if ($default->user_change_fullname) {
      $name = imp_get_fullname($user, $server);
   }
   if (!isset($name) || !$name) $name = '';
   
   if (!isset($from) || !$from || !$default->user_change_from) { 
      $from = '';
      if ($name) {
	 $from  = $name;
	 $from .= ' <';
      }
      $from .= get_barefrom($user, $server);
      if ($name) {
	 $from .= '>'; 
      }
   }
   
   return $from;
}

/* 
 * Replace %ENV_NAME% in string with the respective environmental 
 * variable 
 */
function set_env_in_string($text) {
  while(ereg("%([A-Za-z_]+)%", $text, $regs)) {
    $text = ereg_replace( "%([A-Za-z_]+)%", getenv($regs[1]), $text );
  }
  return $text;
}

/* function that interfaces to sendmail, so from address and all headers
 * are set correctly
 */

function mailfrom($to, $from, $barefrom, $subject, $hdrs, $mesg) {
   global $default;
   
   $hdrs .= "Sender: $barefrom\n";
   if ($default->append_header) {
     $config_hdrs = implode(@file('./config/header.txt'), '');
     $config_hdrs = set_env_in_string($config_hdrs);
     $hdrs .= $config_hdrs;
   }


   if (is_executable($default->path_to_sendmail)) {
      $mail = popen("$default->path_to_sendmail -t -i -f '$barefrom'", 'w');
      
      $result  = fputs($mail, "From: $from\n");
      $result += fputs($mail, "To: $to\n");
      $result += fputs($mail, $hdrs);
      $result += fputs($mail, "Subject: [IMP Problem] $subject\n\n");
      $result += fputs($mail, $mesg);
      
      if (pclose($mail) != 0) $result = 0;
      
   } else {
      
      $hdrs = "From: $from\n" . $hdrs;
      
      if (mail($to, $subject, $mesg, $hdrs)) { $result = 1; }
      else { $result = 0; }
   }
   
   if ($result > 0) { return 1; }
   else { return 0; }
}

$need_horde_db = 1;
$db_lib_loaded = 0;
require ('../lib/horde.lib');
require ('./lib/imp.lib');                   /* IMPlib is the IMP function library  */
require ('./config/defaults.php3');          /* Defaults configuration file         */

/* Html styles configuration */
require('./config/html.php3');
/* Mailbox configuration */
require('./config/mailbox.php3');
/* include mime and language configuration */
require('./config/mime.php3');
require('./config/lang.php3');

require ('./lib/mime.lib');                  /* Mime lib for composing mime messages */
$language = select_lang();
require ("./locale/$language/problem.lang");
require ("./locale/local/problem.lang");

/* Setup the this_client object */
$this_client = new WebClient;

/* send headers to ensure that the page will reload correctly. */
caching_headers();

error_reporting($default->error_level);      /* set error level from imp.lib   */

$session = create_session_object();
$user    = $session->get_user();
$server  = $session->get_server();

/* array to translate string actions into the appropriate integer ID */
if ( ! $this_client->lynx ) {
    $actions[$lang->button_send]          = SEND_MESSAGE;
    $actions[$lang->button_cancel]        = NO_ACTION;
} else {
    $actions[ '[ ' . $lang->button_send . ' ]']          = SEND_MESSAGE;
    $actions[ '[ ' . $lang->button_cancel . ' ]']        = NO_ACTION;
}

/* doctype */
require("$default->include_dir/doctype.inc");

/* Run through action handlers */

if (isset($actionID)) {
    /* translate non-int values into the correct int */
    if (strcspn($actionID, '0123456789')) { $actionID = $actions[$actionID]; }
    
    switch ($actionID) {
	
    case SEND_MESSAGE:
	
	if ($subject && $message) { // need to check to make sure the other parts are there as well
	    /* somehow need to verify email addresses */
	    
	    $mime = new mime_message;
	    $mime->init($message);
	    
	    $text_part = new mime_part;
	    $text_part->type = 'text';
	    $text_part->subtype = 'plain';
	    $text_part->contents = wrap_message($message, 80, "\n");

	    /* add footer to text_part */
	    if ($default->append_trailer) {
		$config_trailer = "\n" . implode(@file('./config/trailer.txt'), '');
		$config_trailer = set_env_in_string($config_trailer);
		$text_part->contents .= $config_trailer;
	    }
	    
	    $mime->add_begin_part($text_part);
	    
	    $msg = $mime->generate();

	    if(isset($user) && isset($server)) {
		$barefrom = get_barefrom($user, $server);
		$from = get_from($user, $server);
	    } else {
		$barefrom = 'mhardy';
		$from = 'mhardy';
	    }
	    
            if ($user == '') {
              $from = 'imp-problem@localhost';
              $barefrom = 'imp-problem@localhost';
            }

	    $hdrs  = "Errors-To: $barefrom\n";
	    $hdrs .= "Reply-To: $from\n";
	    $hdrs .= $mime->header();
	    
	    $hdrs .= 'X-Mailer: IMP/PHP3 Imap webMail Program ' . IMP_VERSION;
	    $hdrs .= "\n";


	    $to = $default->problem_email;
	    
	    if (mailfrom($to, $from, $barefrom, $subject, $hdrs, $msg)) {
		
		/* we succeeded. print success message, load mailbox, and quit */
		status($lang->status_send_success);
		if(! $this_client->lynx ) {
		    echo '<script language="JavaScript">window.location="mailbox.php3"</script></body></html>';
		} else {
		    include( './mailbox.php3' );
		}
		
		exit;
	    }
	} else {

	    /* something wasn't quite right. strange */
	    $ACTION_TEXT = $lang->action_compose;
	    status($lang->status_error_required_field);
	}
	break;
	
    case NO_ACTION:
    default:
	/* load the mailbox.php3 page here - it will bomb out if they aren't logged in */      
	if(! $this_client->lynx ) {
	    echo '<script language="JavaScript">window.location="mailbox.php3"</script></body></html>';
	} else {
	    include( './mailbox.php3' );
	}
	exit;
	break;
	
    }
} else { $ACTION_TEXT = $lang->action_compose; }
if (!isset($status_sent)) { status($lang->status_composition); }

$title = $lang->status_composition;
$sidebar = false;
require("$default->include_dir/generic-header.inc");

$barefrom = get_barefrom($user, $server);
$from = get_from($user, $server);
if (!isset($msg)) { $msg = ''; }
if (!isset($subject)) { $subject = ''; }

if (!$this_client->lynx) {
    include("$default->include_dir/problem/problem.inc");
} else {
    include("$default->include_dir/problem/lynx_problem.inc");
}

require("$default->include_dir/generic-footer.inc");
if (!$this_client->lynx) {
    include("$default->include_dir/problem/javascript.inc");
}

?>
